@@ -1,8 +1,6 @@
 #define XERR
 #include "loop.ih"
 
-// -> ORG/womanloop.cpp
-
 size_t g_caseIdx;           // -> loop.ih       if (caseIdx > 24842)
 size_t g_err = 14;
 
@@ -18,11 +16,9 @@ void Loop::genCases(size_t iter, size_t nCases)
         g_caseIdx = caseIdx;
 
         g_log.caseIdx(caseIdx);
-        caseInit();
+        caseInit();             // initialize the data for this case
 
-        preScreen();        // no action unless screening rounds are specified
-
-        screening();        // same
+        screening();        // no action unless screening rounds are specified
 
         postScreen();
 
@@ -39,4 +35,4 @@ void Loop::genCases(size_t iter, size_t nCases)
 // In the original womanloop function a test is performed whether the
 // woman has died or not. This test is superfluous because if the woman enters
 // postScreen with status PRESENT then in postScreen the status either changes
-// to LEFT_POST or TUMOR_POST.
+// to NATURAL_POST or SELF_POST.
