@@ -2,7 +2,6 @@
 #define INCLUDED_LOOP_
 
 #include <iosfwd>
-#include <unordered_set>
 
 #include "../typedefs/typedefs.h"
 #include "../globals/globals.h"
@@ -24,15 +23,36 @@ namespace FBB
 
 class Loop: public Globals
 {
-    enum Status
+//  Previous enum Status values:
+//      PRESENT,            // 0
+//      LEFT_PRE,           // 1 left the pre, during, post screening
+//      LEFT_DURING,        // 2 (natural death, no tumor)
+//      LEFT_POST,          // 3
+//      TUMOR_PRE,          // 4 tumor 
+//      TUMOR_DURING,       // 5 interval cancer after a screening round
+//      TUMOR_POST,         // 6
+//      UNDETECTED_PRE,     // 7 undetected tumor, nat. death before 1st scr.
+//      UNDETECTED_DURING,  // 8 same, between screening rounds
+//      UNDETECTED_POST,    // 9 same, after the last screening round
+
+    enum Status             // labels in data.cc
     {
         PRESENT,            // 0
-        LEFT_PRE,           // 1 left the pre, during, post screening
-        LEFT_DURING,        // 2
-        LEFT_POST,          // 3
-        TUMOR_PRE,          // 4
-        TUMOR_DURING,       // 5
-        TUMOR_POST,         // 6
+
+        NATURAL_PRE,        // 1 natural death before the 1st screening round
+        UNDETECTED_PRE,     // 2 nat. death, undetected tumor, before 1st scr.
+        SELF_PRE,           // 3 self-detected tumor before 1st scr.
+                          
+        NATURAL_DURING,     // 4 nat. death between screening rounds
+        UNDETECTED_DURING,  // 5 nat. death, undetected tumor, between scr.
+        SELF_DURING,        // 6 self-detected tumor between scr. rounds
+        SCREEN_DETECTED,    // 7 screening-detected tumor
+                          
+        NATURAL_POST,       // 8 nat. death after the last screening round
+        UNDETECTED_POST,    // 9 nat. death, undetected tumor, afer last scr.
+        SELF_POST,          // 10 self-detected tumor after last scr. round
+
+        Status_END   
     };
 
     enum                    // round info (per case) '0': not attended
@@ -60,8 +80,7 @@ class Loop: public Globals
     Modalities d_modalities;
     Screening d_screening;
 
-    bool d_selfDetected;
-    uint16_t d_roundDetected;
+    int16_t d_roundDetected;        // -1: no detection
 
             // Analysis &d_analysis;
 
@@ -73,20 +92,31 @@ class Loop: public Globals
     double d_deathAge = 0;             // actual dying age
 
     uint16_t d_nRounds;                 // from Screening::nRounds()
+
+                                        // when screening is used:
+    uint16_t d_firstRoundAge;           // age of the first screening round
+
     uint16_t d_round = 0;               // currently used screening round
 
     std::string d_roundInfo;
 
-    SizeVect d_nIntervals;
+    SizeVect d_nIntervals;              // # interval cancer per round
+    SizeVect d_nTrueIntervals;          // # interval cancer per round
+                                        //   following a previously attended
+                                        //   screening round
     SizeVect d_nRoundFP;                // # of false-positives per round
     SizeVect d_nRoundFN;                // # of false-negatives per round
 
     SizeVect d_nDetections;
 
     double d_caseCost;
+
+    double d_biopCosts;                 // sum of biop costs per case
+    DoubleVect d_roundBiopCosts;        // and per round
+
     double d_totalCost;
 
-    SizeVect d_roundCost;               // sum of costs over all scr. rounds
+    DoubleVect d_roundCost;             // sum of costs over all scr. rounds
                                         // (org: screeningRoundCosts)
 
                                     // randomly determined (breast cancer)
@@ -103,7 +133,8 @@ class Loop: public Globals
                                             // probGroup::Vector to use when
                                             // constructing d_indices
 
-    static std::unordered_set<std::string> s_availableFiles;
+    static StringSet s_availableFiles;
+    static char const *s_status[];
 
     public:
         Loop(StringVect const &labels);
@@ -111,12 +142,11 @@ class Loop: public Globals
         void iterate();
 
     private:
-                                        // add to totalCost, screeningCose
-        void addCost(double cost);      //+ and womenCost
+        double addBiopCosts(double costs);
+
         bool betaFunction(uint16_t modalityNr);
         void caseInit();
         size_t cases() const;                   // #cases in womenLoop
-        void characteristics(Status natural, Status tumor);
         Uint16Vect cptIndices() const;          // cpt d_indices
         static void fillTNM(std::ostream &out);
         static void fillZeroes(std::ostream &out, size_t idx);
@@ -125,31 +155,36 @@ class Loop: public Globals
         FBB::CSVTable headerRounds(size_t iter) const;
         FBB::CSVTable headerSensitivity() const;
 
-//        void removeCase(double screeningAge, double selfDetectAge);
-        void intervalCancer(double screeningAge);
+        bool intervalCancer();
 
         void labels(std::ostream &out) const;
+
         bool leaving(double screeningAge);
-        void maybeDetect(ModBase *modBase, double screeningAge);
+
+        void maybeFalseNegative(ModBase *modBase, double screeningAge);
+        bool falseNegative(ModBase *modBase);
+        void tumorDetected(ModBase *modBase, double screeningAge);
+
         void maybeFalsePositive(ModBase *modBase, double screeningAge);
+
         double naturalDeathAge();
         static void noTNM(std::ostream &out);
         static std::ofstream open(std::string const &fname);
         static std::ofstream outStream(std::string const &fname, size_t idx);
         void postScreen();
-        void preTumorDeath();   // early natural death
-        void preScreen();
+
         static std::string replaceDollar(std::string const &settingsFile,
                                          size_t idx);
         void resetCounters();
-        void selfDetected();    // self detected the tumor              // .ih
                                             // returns the sensitivity for the
         double sensitivity(ModBase *modBase) const;    // current round  1.cc
-        void setStatus(Status status, double age);
+
+        bool left(Status status, double deathAge);  // also logs the reason
+
         void screen(double screeningAge);
         void screening();
+        std::string showRound() const;
         double treatmentCosts(double screeningAge) const;               // .ih
-        void treatmentDeath();                                          // .ih
 
                 // NOTE: in the orig. source density NRs are used: 1..4
                 //       here density INDICES are usd: 0..3
@@ -163,4 +198,19 @@ class Loop: public Globals
         void writeSensitivity(FBB::CSVTable &sensTable, size_t iter) const;
 };
 
+
+// OBSOLETE
+//        void characteristics(Status natural, Status tumor);
+// OBSOLETE
+//        void preTumorDeath();   // early natural death
+// OBSOLETE
+//        void preScreen();
+// OBSOLETE
+        void preSelfDetected();     // self detected tumor pre-screening
+// OBSOLETE: covered by 'left(...)'
+//      void setStatus(Status status, double age);  // only sets the d_ vars.
+
+//        void removeCase(double screeningAge, double selfDetectAge);
+
+
 #endif
