@@ -26,7 +26,11 @@ class Tumor: public Globals
     };
 
     static unsigned const N_YEARDAYS = 365;
-    static constexpr double NO_TUMOR = -1;
+                                            // initialized tumor age at an
+                                            // impossible age, so always
+                                            // age < tumor age unless there
+                                            // is a tumor (was: -1)
+    static constexpr double NO_TUMOR = END_AGE + END_AGE;
 
     TumorInfo const &d_tumorInfo;
     Growth const &d_growth;
@@ -55,9 +59,6 @@ class Tumor: public Globals
     double d_doublingDays;  // doubling time in days
     double d_doublingYears;  // doubling time in years
 
-                            // only used in reset: no needed as data member
-//    double d_selfDetect;    // self-detect diameter (mm.)
-
     double d_startVolume;
 
     double d_volume;        // actual tumor volume
@@ -74,7 +75,11 @@ class Tumor: public Globals
         void reset();                       // reassign the modifiable members
 
         //operator bool() const; // true: tumor is active .f
-        bool selfDetectable() const;        // true: tumor selfDetectable .f
+
+        bool at(double age) const;      // true: tumor exists at 'age' .f
+
+                                        // true: selfDetect <= 'age'   .f
+        bool selfDetectBefore(double age) const; 
 
         double selfDetectAge() const;       // self-detect age          .f
         double deathAge() const;            // tumor-caused death age   .f
@@ -85,10 +90,9 @@ class Tumor: public Globals
 
         bool metastasis() const;            // only with lung cancer    .f
 
-                    // cpt the tumor's diameter and volume at 'age',
-                    // using the age - d_onset time interval
-        void   characteristics(double age); // at 'age'                 // .cc
-        // void   characteristics();           // at d_selfDetectAge       // .f
+            // cpt the tumor's diameter and volume at 'age' if
+            // d_onset <= age
+        void   characteristicsAt(double age);                           // .cc
 
         void intervalCancer();                                      // .f
 
@@ -118,7 +122,15 @@ class Tumor: public Globals
         static double volume(double diameter);                      // .ih
         static double diameter(double volume);                      // .ih
 
+        static double checkNot(double value);       // -1 at NO_TUMOR  .ih
+
 };
 
+// only used in reset: no needed as data member
+//    double d_selfDetect;    // self-detect diameter (mm.)
+//OBS:
+//        bool selfDetectable() const;        // true: tumor selfDetectable .f
+
+
 #include "tumor.f"
 #endif
