@@ -16,7 +16,7 @@ void Tumor::writeData(CSVTable &tab) const
             // see also modifications (7)
             // //setw(6) << d_selfDetectAge == NO_TUMOR ? 0 : age << '\t' <<
 
-    tab.more() << d_doublingDays << d_prePeriod <<                  // 10 - 11
-                  d_onset << d_selfDetectAge << d_deathAge;         // 12 - 14
-
+    tab.more() << checkNot(d_doublingDays) <<                       // 10
+                  checkNot(d_prePeriod) << checkNot(d_onset) <<     // 11 - 12
+                  checkNot(d_selfDetectAge) << d_deathAge;          //  13 - 14
 }
